Event marker synchronization — BCI-Framework documentation

# Event marker synchronization

    Stimuli delivery > Event synchonization

Is possible to take advantage of the OpenBCI construction, this board includes a set of analog and digital inputs that can be used to synchronize markers. Other systems will need a piece of additional laboratory equipment like LabStreamer that can register time with microseconds precision. In order to use OpenBCI, we will only need an LDR module connected to the pin D11 (or A5) and start the automatic latency correction system. This method is similar to the one implemented by 1.

This simple latency correction consists of a stimuli delivery with only a marker synchronization area, the LDR module is constantly sensing (the boardmode must be in `analog`) so the changes on the square signal are compared with streamed markers and then the latency is corrected. The latency correction only affects the current session, if the framework is restarted this calibration will lose.

For hard event synchronization, is prefer to use the markers synchronization constantly during all run.

1

  Charles E Davis, Jacob G Martin, and Simon J Thorpe. Stimulus onset hub: an open-source, low latency, and opto-isolated trigger box for neuroscientific research replicability and beyond. Frontiers in neuroinformatics, 14:2, 2020.